==> healthrian_visualization_support-1.2.13.tar.gz: lib/src/shared/widget/heart_rate_monitor.dart <==
// ignore_for_file: public_member_api_docs

import 'package:auto_size_text/auto_size_text.dart';
import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_interface/healthrian_ble_interface.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'heart_rate_monitor.g.dart';

_$HeartRateMonitorCWProxy get HeartRateWearEcg =>
    HeartRateMonitor(module: BLEManager().wearEcg12.module).copyWith;

_$HeartRateMonitorCWProxy get HeartRateCardioClick =>
    HeartRateMonitor(module: BLEManager().cardioClick.module).copyWith;

_$HeartRateMonitorCWProxy get HeartRateWearT =>
    HeartRateMonitor(module: BLEManager().wearCardioT.module).copyWith;

@CopyWith()
class HeartRateMonitor extends StatelessWidget {
  const HeartRateMonitor({
    required this.module,
    super.key,
    this.style,
    this.fontSize = 50,
    this.width = 200,
    this.height = 50,
    this.isUsingMean = true,
  });

  final ModuleInterface module;

  final bool isUsingMean;
  final TextStyle? style;
  final double fontSize;
  final double width;
  final double height;

  @override
  Widget build(BuildContext context) {
    final previousValue = <int>[];
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: module.ble.streams.heartRateEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return const SizedBox();
            late final String displayValue;
            if (isUsingMean) {
              previousValue.add(snapshot.data ?? -1);
              if (previousValue.length > 10) previousValue.removeAt(0);

              final sorted = previousValue
                  .where((element) => element > 0)
                  .toList()
                ..sort((a, b) => a - b);
              if (sorted.isEmpty) {
                displayValue = ' - ';
              } else {
                final mid = sorted.length ~/ 2;
                displayValue = sorted[mid].toString();
              }
            } else {
              final value = snapshot.data ?? -1;
              if (value < 0) {
                displayValue = ' - ';
              } else {
                displayValue = value.toString();
              }
            }
            return SizedBox(
              width: width,
              height: height,
              child: AutoSizeText(
                displayValue,
                textAlign: TextAlign.center,
                overflow: TextOverflow.visible,
                style: style?.copyWith(fontSize: fontSize) ??
                    TextStyle(
                      fontSize: fontSize,
                      fontFamily: 'normal',
                    ),
              ),
            );
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.2.22.tar.gz: lib/src/shared/widget/heart_rate_monitor.dart <==
// ignore_for_file: public_member_api_docs

import 'package:auto_size_text/auto_size_text.dart';
import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_interface/healthrian_ble_interface.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'heart_rate_monitor.g.dart';

_$HeartRateMonitorCWProxy get HeartRateWearEcg =>
    HeartRateMonitor(module: BLEManager().wearEcg12.module).copyWith;

_$HeartRateMonitorCWProxy get HeartRateCardioClick =>
    HeartRateMonitor(module: BLEManager().cardioClick.module).copyWith;

_$HeartRateMonitorCWProxy get HeartRateWearT =>
    HeartRateMonitor(module: BLEManager().wearCardioT.module).copyWith;

@CopyWith()
class HeartRateMonitor extends StatelessWidget {
  const HeartRateMonitor({
    required this.module,
    super.key,
    this.style,
    this.fontSize = 50,
    this.width = 200,
    this.height = 50,
    this.isUsingMean = true,
    this.meanListCount = 4,
  });

  final ModuleInterface module;

  final bool isUsingMean;
  final TextStyle? style;
  final double fontSize;
  final double width;
  final double height;

  final int meanListCount;

  @override
  Widget build(BuildContext context) {
    final previousValue = <int>[];
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: module.ble.streams.heartRateEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return const SizedBox();
            late final String displayValue;
            if (isUsingMean) {
              previousValue.add(snapshot.data ?? -1);
              final len = (meanListCount < 4) ? 4 : meanListCount;
              if (previousValue.length > len) previousValue.removeAt(0);

              final sorted = previousValue
                  .where((element) => element > 0)
                  .toList()
                ..sort((a, b) => a - b);
              if (sorted.isEmpty) {
                displayValue = ' - ';
              } else {
                final mid = sorted.length ~/ 2;
                displayValue = sorted[mid].toString();
              }
            } else {
              final value = snapshot.data ?? -1;
              if (value < 0) {
                displayValue = ' - ';
              } else {
                displayValue = value.toString();
              }
            }
            return SizedBox(
              width: width,
              height: height,
              child: AutoSizeText(
                displayValue,
                textAlign: TextAlign.center,
                overflow: TextOverflow.visible,
                style: style?.copyWith(fontSize: fontSize) ??
                    TextStyle(
                      fontSize: fontSize,
                      fontFamily: 'normal',
                    ),
              ),
            );
          },
        );
      },
    );
  }
}
